==> qualityTools_1.45.tar.gz: qualityTools/inst/NEWS.Rd <==
\name{NEWS}
\title{NEWS file for the qualityTools package}

\section{Changes in version 0.87 (1.41)}{
  \itemize{
  
    \item 14. Jul 2011: included the calculation of lambda for a boxcox transformation in function pcr.
    Only specified specification limits are plotted.
    fraction nonconforming are calculated in percentages and ppm
    \item 13. Jul 2011: reference line for Quantil-Quantil and Probability Plots changed
    Anderson Darling test now reports the name of the dataset passed from method pcr
    Reference line of QQ-Plot within method pcr changed
    \item 12. Jul 2011: reference line for normalPlot changed
    Included color coding of sigfnifican effects
    \item 11. Jul 2011: added parameters xlim, ylim and border for qqPlot
    Added parameter border for ppPlot
    
    \item 21. Mar 2011: added missing documentation for S4 classes. 
    Included a visually more appealing DMAIC cycle in the vignette

    \item 26. Feb 2011: Updated the vignette to explain the usage and scope of
    the cg method.
    Updated the vignette to untangle the R-Code used into a file called RCode.R.
    All examples are now easily reproducible.

    \item 11 Feb 2011: gageRRDesign now support nested designs. gageRR can be
    called with method = "nested".
    number of distinctive categories (i.e. ndc) is being calculated within the
    gageRR method
    
    \item 10 Feb 2011: plot method for objects of class gageDesign now includes
    the plotting of Range and Average charts.

    \item 18 Jan 2011: included the gage capability method cg to calculate and
    visualize the cg and cgk index

    \item 10 Dec 2010: gageRR with no interaction term is now calculated
    correctly. Bug in gageRR was found by user.
    
}}

==> qualityTools_1.47.tar.gz: qualityTools/inst/NEWS.Rd <==
\name{NEWS}
\title{NEWS file for the qualityTools package}

\section{Changes in version 0.87 (1.41)}{
  \itemize{
  
    \item 04.08.2011: fixed expected fraction nonconforming calculation (ppm) in method pcr
    corrected the calculation of standard deviation based on subgroups
    \item 27. Jul 2011: in vignette, corrected typo in formula for c_pu i.e. capability for process capability regarding upper specification limit
    \item 14. Jul 2011: included the calculation of lambda for a boxcox transformation in function pcr.
    Only specified specification limits are plotted.
    fraction nonconforming are calculated in percentages and ppm
    \item 13. Jul 2011: reference line for Quantil-Quantil and Probability Plots changed
    Anderson Darling test now reports the name of the dataset passed from method pcr
    Reference line of QQ-Plot within method pcr changed
    \item 12. Jul 2011: reference line for normalPlot changed
    Included color coding of sigfnifican effects
    \item 11. Jul 2011: added parameters xlim, ylim and border for qqPlot
    Added parameter border for ppPlot
    
    \item 21. Mar 2011: added missing documentation for S4 classes. 
    Included a visually more appealing DMAIC cycle in the vignette

    \item 26. Feb 2011: Updated the vignette to explain the usage and scope of
    the cg method.
    Updated the vignette to untangle the R-Code used into a file called RCode.R.
    All examples are now easily reproducible.

    \item 11 Feb 2011: gageRRDesign now support nested designs. gageRR can be
    called with method = "nested".
    number of distinctive categories (i.e. ndc) is being calculated within the
    gageRR method
    
    \item 10 Feb 2011: plot method for objects of class gageDesign now includes
    the plotting of Range and Average charts.

    \item 18 Jan 2011: included the gage capability method cg to calculate and
    visualize the cg and cgk index

    \item 10 Dec 2010: gageRR with no interaction term is now calculated
    correctly. Bug in gageRR was found by user.
    
}}
